==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/communication/kotlin/outputs/DomainPropertiesResponseVerificationStates.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin.outputs

import kotlin.Suppress

/**
 * List of VerificationStatusRecord
 * @property dKIM A class that represents a VerificationStatus record.
 * @property dKIM2 A class that represents a VerificationStatus record.
 * @property dMARC A class that represents a VerificationStatus record.
 * @property domain A class that represents a VerificationStatus record.
 * @property sPF A class that represents a VerificationStatus record.
 */
public data class DomainPropertiesResponseVerificationStates(
    public val dKIM: VerificationStatusRecordResponse? = null,
    public val dKIM2: VerificationStatusRecordResponse? = null,
    public val dMARC: VerificationStatusRecordResponse? = null,
    public val domain: VerificationStatusRecordResponse? = null,
    public val sPF: VerificationStatusRecordResponse? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.communication.outputs.DomainPropertiesResponseVerificationStates):
            DomainPropertiesResponseVerificationStates = DomainPropertiesResponseVerificationStates(
            dKIM = javaType.dKIM().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dKIM2 = javaType.dKIM2().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dMARC = javaType.dMARC().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            domain = javaType.domain().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            sPF = javaType.sPF().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/communication/kotlin/outputs/DomainPropertiesResponseVerificationStates.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin.outputs

import kotlin.Suppress

/**
 * List of VerificationStatusRecord
 * @property dKIM A class that represents a VerificationStatus record.
 * @property dKIM2 A class that represents a VerificationStatus record.
 * @property dMARC A class that represents a VerificationStatus record.
 * @property domain A class that represents a VerificationStatus record.
 * @property sPF A class that represents a VerificationStatus record.
 */
public data class DomainPropertiesResponseVerificationStates(
    public val dKIM: VerificationStatusRecordResponse? = null,
    public val dKIM2: VerificationStatusRecordResponse? = null,
    public val dMARC: VerificationStatusRecordResponse? = null,
    public val domain: VerificationStatusRecordResponse? = null,
    public val sPF: VerificationStatusRecordResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.communication.outputs.DomainPropertiesResponseVerificationStates): DomainPropertiesResponseVerificationStates = DomainPropertiesResponseVerificationStates(
            dKIM = javaType.dKIM().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dKIM2 = javaType.dKIM2().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dMARC = javaType.dMARC().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            domain = javaType.domain().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            sPF = javaType.sPF().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.communication.kotlin.outputs.VerificationStatusRecordResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
